@@ -5,8 +5,6 @@ from datetime import datetime
 from typing import Optional, List, Union
 from enum import EnumMeta
 
-from .data_resource_schema import DataResourceSchema
-
 
 class FileMetadataType(EnumMeta):
     """
@@ -47,7 +45,6 @@ class FileMetadata:
     size: Optional[int] = 0
     uri: Optional[str] = None
     generation: Optional[str] = None
-    metadata: Optional[DataResourceSchema] = None
     digest: Optional[str] = None
     itemCreatedDate: Optional[datetime] = None
     itemUpdatedDate: Optional[datetime] = None
