@@ -3,11 +3,13 @@ from __future__ import annotations
 import inspect
 from dataclasses import dataclass, asdict
 from datetime import datetime, timezone
-from typing import Optional, List, Dict, Union, Any
+from typing import Optional, Union
 
 
-class MetricInput:
+@dataclass
+class MetricInput(dict):
     def __init__(self, key: str, value: Union[float, int], timestamp: Optional[Union[datetime, str]] = None):
+        super().__init__()
         self.key: str = key
         """"""
         self.value: Union[float, int] = value
@@ -32,18 +34,3 @@ class MetricOutput:
 
     def as_dict(self):
         return asdict(self)
-
-
-def create_metrics_input(metrics: Dict[str, float]) -> List[MetricInput]:
-    if len(set(metrics)) < len(metrics):
-        raise ValueError("You can not use the same key value pair more than once.")
-    props: List[MetricInput] = []
-    for key, value in metrics.items():
-        _check_empty_property(key, value)
-        props.append(MetricInput(key, value))
-    return props
-
-
-def _check_empty_property(key: str, value: Any):
-    if key.strip() == "":
-        raise ValueError("Property keys and values can't be empty.")
