@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Optional
 
 
 @dataclass
@@ -7,11 +8,14 @@ class Page:
     simple structure to allow paging when requesting list of elements
     """
 
-    index: int = 1
+    index: Optional[int] = 1
     """
     the index of the page
     """
-    size: int = 100
+    size: Optional[int] = 100
     """
     the size of the page.
     """
+    afterCursor: Optional[bool] = False
+
+    hasNextPage: Optional[bool] = False
